==> allure-report-data-1.4.15-sources.jar: ru/yandex/qatools/allure/data/AllureXUnit.java <==

package ru.yandex.qatools.allure.data;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for allure-x-unit complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="allure-x-unit"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="time" type="{urn:data.allure.qatools.yandex.ru}time"/&gt;
 *         &lt;element name="test-suites" type="{urn:data.allure.qatools.yandex.ru}allure-test-suites" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "allure-x-unit", propOrder = {
    "time",
    "testSuites"
})
public class AllureXUnit {

    @XmlElement(required = true)
    protected Time time;
    @XmlElementWrapper(name = "test-suites")
    @XmlElement(name = "test-suite")
    protected List<AllureTestSuite> testSuites;

    /**
     * Gets the value of the time property.
     * 
     * @return
     *     possible object is
     *     {@link Time }
     *     
     */
    public Time getTime() {
        return time;
    }

    /**
     * Sets the value of the time property.
     * 
     * @param value
     *     allowed object is
     *     {@link Time }
     *     
     */
    public void setTime(Time value) {
        this.time = value;
    }

    public List<AllureTestSuite> getTestSuites() {
        if (testSuites == null) {
            testSuites = new ArrayList<AllureTestSuite>();
        }
        return testSuites;
    }

    public void setTestSuites(List<AllureTestSuite> testSuites) {
        this.testSuites = testSuites;
    }

}

==> allure-report-data-1.5.0-sources.jar: ru/yandex/qatools/allure/data/AllureXUnit.java <==

package ru.yandex.qatools.allure.data;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for allure-x-unit complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="allure-x-unit">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="time" type="{urn:data.allure.qatools.yandex.ru}time"/>
 *         &lt;element name="test-suites" type="{urn:data.allure.qatools.yandex.ru}allure-test-suites" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "allure-x-unit", propOrder = {
    "time",
    "testSuites"
})
public class AllureXUnit {

    @XmlElement(required = true)
    protected Time time;
    @XmlElementWrapper(name = "test-suites")
    @XmlElement(name = "test-suite")
    protected List<AllureTestSuite> testSuites;

    /**
     * Gets the value of the time property.
     * 
     * @return
     *     possible object is
     *     {@link Time }
     *     
     */
    public Time getTime() {
        return time;
    }

    /**
     * Sets the value of the time property.
     * 
     * @param value
     *     allowed object is
     *     {@link Time }
     *     
     */
    public void setTime(Time value) {
        this.time = value;
    }

    public List<AllureTestSuite> getTestSuites() {
        if (testSuites == null) {
            testSuites = new ArrayList<AllureTestSuite>();
        }
        return testSuites;
    }

    public void setTestSuites(List<AllureTestSuite> testSuites) {
        this.testSuites = testSuites;
    }

}
